@@ -1,16 +1,12 @@
-#------------------------------------------------------------------------------
-# Copyright (c) 2005, Enthought, Inc.
+# (C) Copyright 2005-2022 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
-# license included in enthought/LICENSE.txt and may be redistributed only
-# under the conditions described in the aforementioned license.  The license
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
 # is also available online at http://www.enthought.com/licenses/BSD.txt
-# Thanks for using Enthought open source!
 #
-# Author: Enthought, Inc.
-# Description: <Enthought naming package component>
-#------------------------------------------------------------------------------
+# Thanks for using Enthought open source!
 """ Object factory for Python File System contexts. """
 
 
@@ -33,10 +29,8 @@ class PyFSContextFactory(ObjectFactory):
 
         if isinstance(state, Reference):
             if len(state.addresses) > 0:
-                if state.addresses[0].type == 'pyfs_context':
+                if state.addresses[0].type == "pyfs_context":
                     path = state.addresses[0].content
                     obj = context._context_factory(name, path)
 
         return obj
-
-### EOF #######################################################################
