@@ -1,16 +1,12 @@
-#------------------------------------------------------------------------------
-# Copyright (c) 2005, Enthought, Inc.
+# (C) Copyright 2005-2022 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
-# license included in enthought/LICENSE.txt and may be redistributed only
-# under the conditions described in the aforementioned license.  The license
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
 # is also available online at http://www.enthought.com/licenses/BSD.txt
-# Thanks for using Enthought open source!
 #
-# Author: Enthought, Inc.
-# Description: <Enthought naming package component>
-#------------------------------------------------------------------------------
+# Thanks for using Enthought open source!
 """ Object factory for Python File System contexts. """
 
 
@@ -35,9 +31,7 @@ class PyFSObjectFactory(ObjectFactory):
         obj = None
 
         if isinstance(state, Reference):
-            if state.class_name == 'File' and  len(state.addresses) > 0:
+            if state.class_name == "File" and len(state.addresses) > 0:
                 obj = File(state.addresses[0].content)
 
         return obj
-
-### EOF #######################################################################
